@@ -44,6 +44,7 @@ from metafab_python.model.get_currencies200_response_inner import GetCurrencies2
 from metafab_python.model.get_currencies200_response_inner_all_of import GetCurrencies200ResponseInnerAllOf
 from metafab_python.model.get_currency_fees200_response import GetCurrencyFees200Response
 from metafab_python.model.get_exchanges200_response_inner import GetExchanges200ResponseInner
+from metafab_python.model.get_player_data200_response import GetPlayerData200Response
 from metafab_python.model.grant_collection_role_request import GrantCollectionRoleRequest
 from metafab_python.model.grant_currency_role_request import GrantCurrencyRoleRequest
 from metafab_python.model.mint_collection_item_request import MintCollectionItemRequest
@@ -57,6 +58,7 @@ from metafab_python.model.set_collection_approval_request import SetCollectionAp
 from metafab_python.model.set_collection_item_timelock_request import SetCollectionItemTimelockRequest
 from metafab_python.model.set_currency_fees_request import SetCurrencyFeesRequest
 from metafab_python.model.set_exchange_offer_request import SetExchangeOfferRequest
+from metafab_python.model.set_player_data_request import SetPlayerDataRequest
 from metafab_python.model.transaction_model import TransactionModel
 from metafab_python.model.transfer_collection_item_request import TransferCollectionItemRequest
 from metafab_python.model.transfer_currency_request import TransferCurrencyRequest
